@@ -114,6 +114,20 @@ def ceilDiv(n : int, d : int) -> int:
     return -(n // -d)
 
 
+def cloneOleFile(sourcePath, outputPath) -> None:
+    """
+    Uses the OleWriter class to clone the specified OLE file into a new
+    location. Mainly designed for testing.
+    """
+    from .ole_writer import OleWriter
+
+    with olefile.OleFileIO(sourcePath) as f:
+        writer = OleWriter()
+        writer.fromOleFile(f)
+
+    writer.write(outputPath)
+
+
 def createZipOpen(func):
     """
     Creates a wrapper for the open function of a ZipFile that will automatically
@@ -313,6 +327,9 @@ def getCommandArgs(args) -> argparse.Namespace:
     # --skip-embedded
     parser.add_argument('--skip-embedded', dest='skipEmbedded', action='store_true',
                         help='Skips all embedded MSG files when saving attachments.')
+    # --extract-embedded
+    parser.add_argument('--extract-embedded', dest='extractEmbedded', action='store_true',
+                        help='Extracts the embedded MSG files as MSG files instead of running their save functions.')
     # --skip-not-implemented
     parser.add_argument('--skip-not-implemented', '--skip-ni', dest='skipNotImplemented', action='store_true',
                         help='Skips any attachments that are not implemented, allowing saving of the rest of the message.')
@@ -462,14 +479,14 @@ def inputToBytes(stringInputVar, encoding) -> bytes:
         raise ConversionError('Cannot convert to bytes.')
 
 
-def inputToMsgpath(inp) -> List:
+def inputToMsgPath(inp) -> List:
     """
     Converts the input into an msg path.
     """
     if isinstance(inp, (list, tuple)):
         inp = '/'.join(inp)
-    ret = inputToString(inp, 'utf-8').replace('\\', '/').split('/')
-    return ret if ret[0] != '' else []
+    ret = [x for x in inputToString(inp, 'utf-8').replace('\\', '/').split('/') if x]
+    return ret
 
 
 def inputToString(bytesInputVar, encoding) -> str:
@@ -527,9 +544,9 @@ def filetimeToUtc(inp : int) -> float:
     return (inp - 116444736000000000) / 10000000.0
 
 
-def msgpathToString(inp) -> str:
+def msgPathToString(inp) -> str:
     """
-    Converts an msgpath (one of the internal paths inside an msg file) into a
+    Converts an MSG path (one of the internal paths inside an MSG file) into a
     string.
     """
     if inp is None:
